@@ -8,6 +8,9 @@ A module that contains the templates for the reports and functions to format dat
 import os
 import io
 from datetime import datetime
+import logging
+
+log = logging.getLogger('sweeper')
 
 def _print_items(report, key, writer):
     '''print out issues or fixes
@@ -67,8 +70,8 @@ def _generate_report(writer, reports):
 def save_report(reports, save_directory):
     '''
     save_directory
-      - folder sweeper-run-{date}
-        - feature class name-sweeper name-numberofissues.txt `Counties-Empties-5.txt`   `Counties-Empties-0.txt`
+      - folder sweeper_run_YYYYMMDD_HHmm
+        - featureclassname_sweepername_numberofissues.txt `Counties_Empties_5.txt`   `Counties_Empties_0.txt`
     '''
     report_directory = _create_report_directory(save_directory)
 
@@ -103,7 +106,66 @@ def format_message(reports):
     now = datetime.now().strftime('%Y%m%d_%H%M')
     message.write(f'<pre>Email summary for {now} Sweeper run \n\n</pre>')
 
-    for report in reports:
-        message.write(f'<pre>{len(report["issues"]):4} Issues \t {report["title"]:<16} \t {report["feature_class"]:<50} \n</pre>')
+    if not reports:
+        message.write('<pre>No changes identified or Sweeper tests run\n</pre>')
+    else:
+        for report in reports:
+            message.write(f'<pre>{len(report["issues"]):4} Issues \t {report["title"]:<16} \t {report["feature_class"]:<50} \n</pre>')
 
     return message
+
+
+def _log_items(report, key):
+    '''print out issues or fixes to log
+    report: report dictionary
+    key: 'issues' | 'fixes'
+    '''
+    try:
+        items = report[key]
+    except KeyError:
+        return
+
+    items_found = len(items)
+    if items_found == 0:
+        log.info(f'No {key} found!')
+        log.info('---')
+
+        return
+
+    log.info(f'{items_found} {key} found:')
+
+    has_oids = True
+    if isinstance(items, list):
+        for item in items:
+            if isinstance(item, int):
+                log.info(f'    ObjectID {item}')
+            else:
+                #: issues not associated with a specific row (e.g. metadata)
+                has_oids = False
+                log.info(f'    {item}')
+    else:
+        #: must be dict
+        for oid in items:
+            log.info(f'    ObjectID {oid}: {items[oid]}')
+
+    if has_oids:
+        log.info(f'\nSelect statement to view {key} in ArcGIS:')
+        statement = f'OBJECTID IN ({", ".join([str(oid) for oid in items])})'
+
+        log.info(statement)
+
+    log.info('---')
+
+
+def add_to_log(reports):
+    if len(reports) == 0:
+        log.info('No issues found!')
+
+        return None
+
+    #: loop through each report dict in the list of dicts
+    for report in reports:
+        log.info(f'{report["title"]} Report for {report["feature_class"]}')
+
+        _log_items(report, 'fixes')
+        _log_items(report, 'issues')
